---
title: autostart
keywords: documentation
layout: documentation
sidebar: iib_install_sidebar
toc: false
---
## Overview

This defined type makes sure the specfied IIB broker is automaticaly started at system start.

Here is an example on how to use it:

``` puppet
iib_install::autostart { 'IIBBROKER1':
  ensure       => 'present',
  path         => '/etc/systemd/system',
  service_name => 'iib@',
  install_root => '/opt/IBM',
  iib_version  => '10.0.0.9',
  iib_user     => 'iibadmin',
  iib_group    => 'mqbrkrs',
}
```




## Attributes



Attribute Name                          | Short Description                                                           |
--------------------------------------- | --------------------------------------------------------------------------- |
[ensure](#autostart_ensure)             | Tells if you want to make sure the broker is either there or not.           |
[iib_group](#autostart_iib_group)       | Allows you to specify the OS group the IIB broker will be started under.    |
[iib_user](#autostart_iib_user)         | Allows you to specify the OS user the IIB broker will be started under.     |
[iib_version](#autostart_iib_version)   | Specifies the version of IIB that is used for this autostart.               |
[install_root](#autostart_install_root) | Specfies the base path where the software used for the broker, is located,
 |
[path](#autostart_path)                 | Allows you to specify the path where the unit-file will be placed.          |
[service_name](#autostart_service_name) | Allows you to specfy the name of the service.                               |




### ensure<a name='autostart_ensure'>

Tells if you want to make sure the broker is either there or not.

This property has twho possible values `present`, which makes sure the broker autostart is present, or `absent` which makes sure there is no autostart beeing applied to this broker.

Here is an example on how to use it:

```puppet
iib_install::autostart { 'IIBBROKER1':
  ...
  ensure       => 'present',
  ...
}
```
[Back to overview of autostart](#attributes)


### path<a name='autostart_path'>

Allows you to specify the path where the unit-file will be placed.

Here is an example on how to use this:

``` puppet
iib_install::autostart{'IIBBROKER1':
  ...
  path         => '/etc/mysystemd/system',
  ...
}
```

The default value is `/etc/systemd/system'.

[Back to overview of autostart](#attributes)


### service_name<a name='autostart_service_name'>

Allows you to specfy the name of the service.

Here is an example on how to use this:

``` puppet
iib_install::autostart{'IIBBROKER1':
  ...
  service_name => 'my_iib,
  ...
}
```

The default value is : `"iib@$broker_name`.
[Back to overview of autostart](#attributes)


### install_root<a name='autostart_install_root'>

Specfies the base path where the software used for the broker, is located,

Together with the `iib_version` parameter, this makes the full-path.

``` puppet
iib_install::autostart { 'IIBBROKER1':
  ...
  install_root => '/opt/IBM',
  ...
}
```

[Back to overview of autostart](#attributes)


### iib_version<a name='autostart_iib_version'>

Specifies the version of IIB that is used for this autostart.

This parameter is used to construct the path of the software. 

Here is an example on how to use it:

``` puppet
iib_install::autostart { 'IIBBROKER1':
  ...
  iib_version  => '10.0.0.9',
  ...
}
```

[Back to overview of autostart](#attributes)


### iib_user<a name='autostart_iib_user'>

Allows you to specify the OS user the IIB broker will be started under.

Here is an example on how to use this:

``` puppet
iib_install::autostart{'IIBBROKER1':
  ...
  iib_user      => 'myuser',
  ...
}
```

The default value is `miibadmin` and is correct in most situations.
[Back to overview of autostart](#attributes)


### iib_group<a name='autostart_iib_group'>

Allows you to specify the OS group the IIB broker will be started under.

Here is an example on how to use this:

``` puppet
iib_install::autostart{'BROKER1':
  ...
  iib_group     => 'mygroup',
  ...
}
```

The default value is `mqbrkrs` and is correct in most situations.
[Back to overview of autostart](#attributes)

