#
# See the file "LICENSE" for the full license governing this code.
#
#
# This defined type create's an startup unit or startuup script for starting the named
# queue manager. It also create's the service and enables it.
#
define iib_install::autostart(
  Enum['present', 'absent'] $ensure = 'present',
  String  $path                     = lookup('iib_install::autostart::path'),
  String  $service_name             = lookup('iib_install::autostart::service_name'),
  String  $install_root             = lookup('iib_install::autostart::install_root'),
  String  $iib_version              = lookup('iib_install::autostart::iib_version'),
  String  $iib_user                 = lookup('iib_install::autostart::iib_user'),
  String  $iib_group                = lookup('iib_install::autostart::iib_group'),
)
{
  iib_install { "iib_install::autostart::${title}": }
  if $::osfamily == 'windows' { fail 'This module does not support Windows'}
  if $::systemd == undef  { fail 'Module camptocamp-systemd required. Probably not installed'}

  assert_type(Pattern[/\d+\.\d+\.\d+\.\d/], $iib_version) |$expected, $actual| {
    fail 'Invalid version specified'
  }

  case($ensure) {
    'absent':  {
      $service_ensure =  'stopped'
      $service_enable =  false
    }
    'present': {
      $service_ensure = 'running'
      $service_enable =  true
    }
    default: { fail('Invalid value for ensure found.')}
  }

  $iib_node_name = $title

  file {'/usr/local/bin/iibcmd':
    ensure  => 'present',
    content => epp('iib_install/iibcmd.epp', {
      'install_root' => $install_root,
      'iib_version'  => $iib_version,
      }),
    mode    => '0755',
  }

  if $::systemd {
    ::systemd::unit_file { "${service_name}.service":
      ensure  => $ensure,
      path    => $path,
      content => epp('iib_install/iib.service.epp', {
        'iib_version' => $iib_version,
        'iib_user'    => $iib_user,
        'iib_group'   => $iib_group,
        }),
      notify  => Service["${service_name}${iib_node_name}"],
    }

    # #
    # # When iib_broker starts the broker, it does so outside of the systemd context. To make
    # # sure we can start it with systemd, we first have to stop it and then start the service.
    # #
    -> exec {"stop ${iib_node_name} running outside systemd":
      command => "/usr/local/bin/iibcmd mqsistop ${iib_node_name}",
      path    => '/bin',
      user    => $iib_user,
      group   => $iib_group,
      onlyif  => "ps -eaf | grep 'bipbroker [${iib_node_name}]'",
      unless  => "systemctl --state running | grep ${iib_node_name}",
    }

    service {"${service_name}${iib_node_name}":
      ensure => $service_ensure,
      enable => $service_enable,
    }
  } else {

    file { "${path}/iib":
      ensure  => $ensure,
      content => epp('iib_install/iib.epp', {
        'install_root' => $install_root,
        'iib_version'  => $iib_version,
        'iib_user'     => $iib_user,
        }),
      mode    => '0755',
    }

    ~>service {$service_name:
      ensure => $service_ensure,
      enable => $service_enable,
    }
  }
}
